@@ -25,6 +25,7 @@ from .csim import Csim
 from .cubebel1 import Cubebel1
 from .cubesatsim import Cubesatsim
 from .delfin3xt import Delfin3xt
+from .diy1 import Diy1
 from .duchifat3 import Duchifat3
 from .elfin import Elfin
 from .entrysat import Entrysat
@@ -39,9 +40,11 @@ from .ksu import Ksu
 from .lightsail2 import Lightsail2
 from .meznsat import Meznsat
 from .minxss import Minxss
+from .mirsat1 import Mirsat1
 from .mitee1 import Mitee1
 from .mxl import Mxl
 from .mysat import Mysat
+from .netsat import Netsat
 from .neutron1 import Neutron1
 from .opssat1 import Opssat1
 from .origamisat1 import Origamisat1
@@ -52,6 +55,7 @@ from .qarman import Qarman
 from .qbee import Qbee
 from .qubik import Qubik
 from .quetzal1 import Quetzal1
+from .salsat import Salsat
 from .siriussat import Siriussat
 from .skcube import Skcube
 from .spoc import Spoc
@@ -80,6 +84,7 @@ __all__ = [
     'Cubesatsim',
     'Csim',
     'Delfin3xt',
+    'Diy1',
     'Duchifat3',
     'Elfin',
     'Entrysat',
@@ -95,8 +100,10 @@ __all__ = [
     'Meznsat',
     'Minxss',
     'Mitee1',
+    'Mirsat1',
     'Mxl',
     'Mysat',
+    'Netsat',
     'Neutron1',
     'Opssat1',
     'Origamisat1',
@@ -107,6 +114,7 @@ __all__ = [
     'Qbee',
     'Qubik',
     'Quetzal1',
+    'Salsat',
     'Siriussat',
     'Skcube',
     'Spoc',
